require './gphys_const_v1.1'
require "numru/ggraph"
include NumRu

#dir = '..'
#dir = '../util_s2p-2011-12-15/out'
#dir = '../util_s2p-2012-09-12/out'
dir = '../util_timemean-2012-11-02/out'

daysOfYear = 0
DaysOfMonth.each do |i|
  daysOfYear += i
end
p 'DEBUG: days in a year: ' + daysOfYear.to_s

figdir = 'figs'
#Dir::mkdir( figdir )

vnames = ['Temp', 'U', 'V', 'OMG', 'MSF', 'ANGMOM','epflx_div']

iyrs = 3
iyre = 3
iyrs = 1
iyre = 1

for ivar in 0..(vnames.length-1)
#  for imon in 1..12
  for imon in 1..1
    p vnames[ivar] + ' at Year: ' + iyrs.to_s + ' to ' + iyre.to_s + ', Month: ' + imon.to_s

    system('ruby draw_3D_zm_log.rb ' + dir + ' ' + vnames[ivar] + ' ' + iyrs.to_s + ' ' + iyre.to_s + ' ' + imon.to_s)

    system("pstoimg -type gif -flip r270 dcl.ps")
    com = sprintf( "mv dcl.gif " + figdir + "/dcl_zm_log_"+vnames[ivar]+"_mon%0#{2}d.gif", imon )
    system(com)
    com = sprintf( "mv dcl.ps " + figdir + "/dcl_zm_log_"+vnames[ivar]+"_mon%0#{2}d.ps", imon )
    system(com)
  end
end
